# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ZoneArgs', 'Zone']

@pulumi.input_type
class ZoneArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Zone resource.
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        pulumi.set(__self__, "type", type)
        if asns is not None:
            pulumi.set(__self__, "asns", asns)
        if dynamic_locations is not None:
            pulumi.set(__self__, "dynamic_locations", dynamic_locations)
        if dynamic_locations_excludes is not None:
            pulumi.set(__self__, "dynamic_locations_excludes", dynamic_locations_excludes)
        if dynamic_proxy_type is not None:
            pulumi.set(__self__, "dynamic_proxy_type", dynamic_proxy_type)
        if gateways is not None:
            pulumi.set(__self__, "gateways", gateways)
        if ip_service_categories_excludes is not None:
            pulumi.set(__self__, "ip_service_categories_excludes", ip_service_categories_excludes)
        if ip_service_categories_includes is not None:
            pulumi.set(__self__, "ip_service_categories_includes", ip_service_categories_includes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if proxies is not None:
            pulumi.set(__self__, "proxies", proxies)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @asns.setter
    def asns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asns", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @dynamic_locations.setter
    def dynamic_locations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @dynamic_locations_excludes.setter
    def dynamic_locations_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations_excludes", value)

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @dynamic_proxy_type.setter
    def dynamic_proxy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dynamic_proxy_type", value)

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @gateways.setter
    def gateways(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "gateways", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @ip_service_categories_excludes.setter
    def ip_service_categories_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_excludes", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @ip_service_categories_includes.setter
    def ip_service_categories_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_includes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @proxies.setter
    def proxies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "proxies", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage", value)


@pulumi.input_type
class _ZoneState:
    def __init__(__self__, *,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Zone resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        if asns is not None:
            pulumi.set(__self__, "asns", asns)
        if dynamic_locations is not None:
            pulumi.set(__self__, "dynamic_locations", dynamic_locations)
        if dynamic_locations_excludes is not None:
            pulumi.set(__self__, "dynamic_locations_excludes", dynamic_locations_excludes)
        if dynamic_proxy_type is not None:
            pulumi.set(__self__, "dynamic_proxy_type", dynamic_proxy_type)
        if gateways is not None:
            pulumi.set(__self__, "gateways", gateways)
        if ip_service_categories_excludes is not None:
            pulumi.set(__self__, "ip_service_categories_excludes", ip_service_categories_excludes)
        if ip_service_categories_includes is not None:
            pulumi.set(__self__, "ip_service_categories_includes", ip_service_categories_includes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if proxies is not None:
            pulumi.set(__self__, "proxies", proxies)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @asns.setter
    def asns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asns", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @dynamic_locations.setter
    def dynamic_locations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @dynamic_locations_excludes.setter
    def dynamic_locations_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations_excludes", value)

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @dynamic_proxy_type.setter
    def dynamic_proxy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dynamic_proxy_type", value)

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @gateways.setter
    def gateways(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "gateways", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @ip_service_categories_excludes.setter
    def ip_service_categories_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_excludes", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @ip_service_categories_includes.setter
    def ip_service_categories_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_includes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @proxies.setter
    def proxies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "proxies", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage", value)


@pulumi.type_token("okta:network/zone:Zone")
class Zone(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Okta Network Zone. This resource allows you to create and configure an Okta Network Zone.

        ## Import

        ```sh
        $ pulumi import okta:network/zone:Zone example <zone_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Okta Network Zone. This resource allows you to create and configure an Okta Network Zone.

        ## Import

        ```sh
        $ pulumi import okta:network/zone:Zone example <zone_id>
        ```

        :param str resource_name: The name of the resource.
        :param ZoneArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneArgs.__new__(ZoneArgs)

            __props__.__dict__["asns"] = asns
            __props__.__dict__["dynamic_locations"] = dynamic_locations
            __props__.__dict__["dynamic_locations_excludes"] = dynamic_locations_excludes
            __props__.__dict__["dynamic_proxy_type"] = dynamic_proxy_type
            __props__.__dict__["gateways"] = gateways
            __props__.__dict__["ip_service_categories_excludes"] = ip_service_categories_excludes
            __props__.__dict__["ip_service_categories_includes"] = ip_service_categories_includes
            __props__.__dict__["name"] = name
            __props__.__dict__["proxies"] = proxies
            __props__.__dict__["status"] = status
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["usage"] = usage
        super(Zone, __self__).__init__(
            'okta:network/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
            gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            usage: Optional[pulumi.Input[_builtins.str]] = None) -> 'Zone':
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneState.__new__(_ZoneState)

        __props__.__dict__["asns"] = asns
        __props__.__dict__["dynamic_locations"] = dynamic_locations
        __props__.__dict__["dynamic_locations_excludes"] = dynamic_locations_excludes
        __props__.__dict__["dynamic_proxy_type"] = dynamic_proxy_type
        __props__.__dict__["gateways"] = gateways
        __props__.__dict__["ip_service_categories_excludes"] = ip_service_categories_excludes
        __props__.__dict__["ip_service_categories_includes"] = ip_service_categories_includes
        __props__.__dict__["name"] = name
        __props__.__dict__["proxies"] = proxies
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        __props__.__dict__["usage"] = usage
        return Zone(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def usage(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")

