# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AdminRoleCustomAssignmentsArgs', 'AdminRoleCustomAssignments']

@pulumi.input_type
class AdminRoleCustomAssignmentsArgs:
    def __init__(__self__, *,
                 custom_role_id: pulumi.Input[_builtins.str],
                 resource_set_id: pulumi.Input[_builtins.str],
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a AdminRoleCustomAssignments resource.
        :param pulumi.Input[_builtins.str] custom_role_id: ID of the Custom Role
        :param pulumi.Input[_builtins.str] resource_set_id: ID of the target Resource Set
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: The hrefs that point to User(s) and/or Group(s) that receive the Role
        """
        pulumi.set(__self__, "custom_role_id", custom_role_id)
        pulumi.set(__self__, "resource_set_id", resource_set_id)
        if members is not None:
            pulumi.set(__self__, "members", members)

    @_builtins.property
    @pulumi.getter(name="customRoleId")
    def custom_role_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the Custom Role
        """
        return pulumi.get(self, "custom_role_id")

    @custom_role_id.setter
    def custom_role_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "custom_role_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the target Resource Set
        """
        return pulumi.get(self, "resource_set_id")

    @resource_set_id.setter
    def resource_set_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_set_id", value)

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The hrefs that point to User(s) and/or Group(s) that receive the Role
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "members", value)


@pulumi.input_type
class _AdminRoleCustomAssignmentsState:
    def __init__(__self__, *,
                 custom_role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AdminRoleCustomAssignments resources.
        :param pulumi.Input[_builtins.str] custom_role_id: ID of the Custom Role
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: The hrefs that point to User(s) and/or Group(s) that receive the Role
        :param pulumi.Input[_builtins.str] resource_set_id: ID of the target Resource Set
        """
        if custom_role_id is not None:
            pulumi.set(__self__, "custom_role_id", custom_role_id)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if resource_set_id is not None:
            pulumi.set(__self__, "resource_set_id", resource_set_id)

    @_builtins.property
    @pulumi.getter(name="customRoleId")
    def custom_role_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Custom Role
        """
        return pulumi.get(self, "custom_role_id")

    @custom_role_id.setter
    def custom_role_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_role_id", value)

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The hrefs that point to User(s) and/or Group(s) that receive the Role
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "members", value)

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the target Resource Set
        """
        return pulumi.get(self, "resource_set_id")

    @resource_set_id.setter
    def resource_set_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_set_id", value)


@pulumi.type_token("okta:index/adminRoleCustomAssignments:AdminRoleCustomAssignments")
class AdminRoleCustomAssignments(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource to manage the assignment and unassignment of Custom Roles
        These operations allow the creation and manipulation of custom roles as custom collections of permissions.

        > **NOTE:** This an Early Access feature.

        ## Import

        ```sh
        $ pulumi import okta:index/adminRoleCustomAssignments:AdminRoleCustomAssignments example <resource_set_id>/<custom_role_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] custom_role_id: ID of the Custom Role
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: The hrefs that point to User(s) and/or Group(s) that receive the Role
        :param pulumi.Input[_builtins.str] resource_set_id: ID of the target Resource Set
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AdminRoleCustomAssignmentsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource to manage the assignment and unassignment of Custom Roles
        These operations allow the creation and manipulation of custom roles as custom collections of permissions.

        > **NOTE:** This an Early Access feature.

        ## Import

        ```sh
        $ pulumi import okta:index/adminRoleCustomAssignments:AdminRoleCustomAssignments example <resource_set_id>/<custom_role_id>
        ```

        :param str resource_name: The name of the resource.
        :param AdminRoleCustomAssignmentsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AdminRoleCustomAssignmentsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AdminRoleCustomAssignmentsArgs.__new__(AdminRoleCustomAssignmentsArgs)

            if custom_role_id is None and not opts.urn:
                raise TypeError("Missing required property 'custom_role_id'")
            __props__.__dict__["custom_role_id"] = custom_role_id
            __props__.__dict__["members"] = members
            if resource_set_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_set_id'")
            __props__.__dict__["resource_set_id"] = resource_set_id
        super(AdminRoleCustomAssignments, __self__).__init__(
            'okta:index/adminRoleCustomAssignments:AdminRoleCustomAssignments',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_role_id: Optional[pulumi.Input[_builtins.str]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            resource_set_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AdminRoleCustomAssignments':
        """
        Get an existing AdminRoleCustomAssignments resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] custom_role_id: ID of the Custom Role
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: The hrefs that point to User(s) and/or Group(s) that receive the Role
        :param pulumi.Input[_builtins.str] resource_set_id: ID of the target Resource Set
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AdminRoleCustomAssignmentsState.__new__(_AdminRoleCustomAssignmentsState)

        __props__.__dict__["custom_role_id"] = custom_role_id
        __props__.__dict__["members"] = members
        __props__.__dict__["resource_set_id"] = resource_set_id
        return AdminRoleCustomAssignments(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="customRoleId")
    def custom_role_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the Custom Role
        """
        return pulumi.get(self, "custom_role_id")

    @_builtins.property
    @pulumi.getter
    def members(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The hrefs that point to User(s) and/or Group(s) that receive the Role
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the target Resource Set
        """
        return pulumi.get(self, "resource_set_id")

